@@ -55,16 +55,11 @@
 
 #else
 
-#define COLOR_BG            color16(0, 0, 0)
+#define COLOR_BG            color16(2, 8, 10)
 
 #define color16(red, green, blue)                                             \
   (red << 11) | (green << 5) | blue                                           \
 
-#ifdef MAEMO
-
-#define COLOR_BG            color16(2, 8, 10)
-
-#endif
 #endif
 
 #define COLOR_ROM_INFO      color16(22, 36, 26)
@@ -758,7 +753,7 @@ static const char *scale_options[] =
 #elif defined(WIZ_BUILD)
   "unscaled 3:2", "scaled 3:2 (slower)",
   "unscaled 3:2 (anti-tear)", "scaled 3:2 (anti-tear)"
-#elif defined(PND_BUILD)
+#elif defined(MAEMO)
   "unscaled", "2x", "3x", "fullscreen"
 #elif defined(GP2X_BUILD)
   "unscaled 3:2", "scaled 3:2", "fullscreen", "scaled 3:2 (software)"
@@ -1490,7 +1485,7 @@ u32 menu(u16 *original_screen)
 
 #endif
 
-#if defined(GP2X_BUILD) || defined(PND_BUILD)
+#if defined(GP2X_BUILD) || defined(MAEMO)
 
   menu_option_type gamepad_config_options[] =
   {
@@ -1510,10 +1505,10 @@ u32 menu(u16 *original_screen)
     gamepad_config_option("Start        ", 10),
 #endif
     gamepad_config_option("Select       ", 11),
-#if !defined(WIZ_BUILD) && !defined(PND_BUILD)
+#if !defined(WIZ_BUILD) && !defined(MAEMO)
     gamepad_config_option("Stick Push   ", 12),
 #endif
-#ifdef PND_BUILD
+#ifdef MAEMO
     gamepad_config_option("1            ", 12),
     gamepad_config_option("2            ", 13),
     gamepad_config_option("3            ", 14),
